@@ -1,13 +1,13 @@
 from typing import AsyncGenerator
 
 from fastapi import Depends
-from fastapi_users_db_sqlalchemy import SQLAlchemyUserDatabase
+from fastapi_users_db_sqlalchemy import SQLAlchemyUserDatabase, \
+    SQLAlchemyBaseUserTableUUID
 from sqlalchemy.ext.asyncio import AsyncSession, create_async_engine
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import sessionmaker
 
 from defi_common import dbconfig
-from defi_common.database.models import User
 
 DATABASE_URL = dbconfig.db_config.db_url
 
@@ -28,5 +28,10 @@ async def get_session() -> AsyncGenerator:  # type: ignore
         yield session
 
 
-async def get_user_db(session: AsyncSession = Depends(get_session)) -> AsyncGenerator: #type: ignore
+class User(SQLAlchemyBaseUserTableUUID, Base):
+    pass
+
+
+async def get_user_db(
+        session: AsyncSession = Depends(get_session)) -> AsyncGenerator:  # type: ignore
     yield SQLAlchemyUserDatabase(session, User)
